@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.013';
+our $VERSION = '0.014';
 $VERSION = eval $VERSION; ## no critic
 
 use Archive::Extract;
@@ -117,7 +117,7 @@ sub _search_from_start_dir {
                 if ( defined $args->{pattern} ) {
                     return unless $_ =~ m/$args->{pattern}/;
                 }
-                push @found, $File::Find::name;
+                push @found, File::Spec->canonpath($File::Find::name);
             },
         },
         $self->{start_dir},
